@@ -4,5 +4,8 @@ from ._dirichlet_process import DirichletProcess
 from ._pitman_yor_process import PitmanYorProcess
 from ._geometric_process import GeometricProcess
 from ._beta_in_beta import BetaInBeta
+from ._beta_in_dirichlet import BetaInDirichlet
 from ._beta_bernoulli import BetaBernoulli
 from ._beta_binomial import BetaBinomial
+from ._equal import EqualWeighting
+from ._frequency import FrequencyWeighting
